# Dynamic Single Objective Optimization  in Python

[![License](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pydsoo)
[![PyPI](https://img.shields.io/pypi/v/pydsoo)](https://pypi.org/project/pydsoo/)
![Visitors](https://visitor-badge.laobi.icu/badge?page_id=dynoptimization.pydsoo)
